@@ -34,44 +34,54 @@ class SqlAlchemyConnectionTest(TestCase):
         engine = sa.create_engine('crate://')
         conn = engine.raw_connection()
         self.assertEqual("<Connection <Client ['http://127.0.0.1:4200']>>",
-                         repr(conn.connection))
+                         repr(conn.driver_connection))
+        conn.close()
+        engine.dispose()
 
     def test_connection_server_uri_http(self):
         engine = sa.create_engine(
             "crate://otherhost:19201")
         conn = engine.raw_connection()
         self.assertEqual("<Connection <Client ['http://otherhost:19201']>>",
-                         repr(conn.connection))
+                         repr(conn.driver_connection))
+        conn.close()
+        engine.dispose()
 
     def test_connection_server_uri_https(self):
         engine = sa.create_engine(
             "crate://otherhost:19201/?ssl=true")
         conn = engine.raw_connection()
         self.assertEqual("<Connection <Client ['https://otherhost:19201']>>",
-                         repr(conn.connection))
+                         repr(conn.driver_connection))
+        conn.close()
+        engine.dispose()
 
     def test_connection_server_uri_invalid_port(self):
         with self.assertRaises(ValueError) as context:
             sa.create_engine("crate://foo:bar")
-        self.assertTrue("invalid literal for int() with base 10: 'bar'" in str(context.exception))
+        self.assertIn("invalid literal for int() with base 10: 'bar'", str(context.exception))
 
     def test_connection_server_uri_https_with_trusted_user(self):
         engine = sa.create_engine(
             "crate://foo@otherhost:19201/?ssl=true")
         conn = engine.raw_connection()
         self.assertEqual("<Connection <Client ['https://otherhost:19201']>>",
-                         repr(conn.connection))
-        self.assertEqual(conn.connection.client.username, "foo")
-        self.assertEqual(conn.connection.client.password, None)
+                         repr(conn.driver_connection))
+        self.assertEqual(conn.driver_connection.client.username, "foo")
+        self.assertEqual(conn.driver_connection.client.password, None)
+        conn.close()
+        engine.dispose()
 
     def test_connection_server_uri_https_with_credentials(self):
         engine = sa.create_engine(
             "crate://foo:bar@otherhost:19201/?ssl=true")
         conn = engine.raw_connection()
         self.assertEqual("<Connection <Client ['https://otherhost:19201']>>",
-                         repr(conn.connection))
-        self.assertEqual(conn.connection.client.username, "foo")
-        self.assertEqual(conn.connection.client.password, "bar")
+                         repr(conn.driver_connection))
+        self.assertEqual(conn.driver_connection.client.username, "foo")
+        self.assertEqual(conn.driver_connection.client.password, "bar")
+        conn.close()
+        engine.dispose()
 
     def test_connection_multiple_server_http(self):
         engine = sa.create_engine(
@@ -83,7 +93,9 @@ class SqlAlchemyConnectionTest(TestCase):
         self.assertEqual(
             "<Connection <Client ['http://localhost:4201', " +
             "'http://localhost:4202']>>",
-            repr(conn.connection))
+            repr(conn.driver_connection))
+        conn.close()
+        engine.dispose()
 
     def test_connection_multiple_server_https(self):
         engine = sa.create_engine(
@@ -96,4 +108,6 @@ class SqlAlchemyConnectionTest(TestCase):
         self.assertEqual(
             "<Connection <Client ['https://localhost:4201', " +
             "'https://localhost:4202']>>",
-            repr(conn.connection))
+            repr(conn.driver_connection))
+        conn.close()
+        engine.dispose()
